==> haskell-polyparse-1.13-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polyparse
version:              1.13
visibility:           public
id:                   polyparse-1.13-6qWX0TBgzpT5PvWL8guBB0
key:                  polyparse-1.13-6qWX0TBgzpT5PvWL8guBB0
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           author
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://code.haskell.org/~malcolm/polyparse/
synopsis:             A variety of alternative parser combinator libraries.
description:
    This version, 1.13 is a Non-Maintainer Upload (NMU).
    Report issues to the Hackage Trustees issue tracker.

    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

category:             Text, Parsing
abi:                  2a2c8358ffbb3796bfcf52adf44aa0cf
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.0.2/site-local/polyparse-1.13
library-dirs:         /usr/lib/ghc-9.0.2/site-local/polyparse-1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/polyparse-1.13
hs-libraries:         HSpolyparse-1.13-6qWX0TBgzpT5PvWL8guBB0
depends:              base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polyparse-1.13-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polyparse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polyparse
version:              1.13
visibility:           public
id:                   polyparse-1.13-I1ahtjDxVhG8wUoxrQsnyB
key:                  polyparse-1.13-I1ahtjDxVhG8wUoxrQsnyB
license:              LicenseRef-LGPL
copyright:            (c) 2006-2016 Malcolm Wallace
maintainer:           author
author:               Malcolm Wallace <Malcolm.Wallace@me.com>
homepage:             http://code.haskell.org/~malcolm/polyparse/
synopsis:             A variety of alternative parser combinator libraries.
description:
    This version, 1.13 is a Non-Maintainer Upload (NMU).
    Report issues to the Hackage Trustees issue tracker.

    A variety of alternative parser combinator libraries, including
    the original HuttonMeijer set.  The Poly sets have features like
    good error reporting, arbitrary token type, running state, lazy
    parsing, and so on.  Finally, Text.Parse is a proposed
    replacement for the standard Read class, for better
    deserialisation of Haskell values from Strings.

category:             Text, Parsing
abi:                  787982b6b1684a75638f579be5000f12
exposed:              True
exposed-modules:
    Text.Parse Text.Parse.ByteString
    Text.ParserCombinators.HuttonMeijer
    Text.ParserCombinators.HuttonMeijerWallace
    Text.ParserCombinators.Poly Text.ParserCombinators.Poly.Base
    Text.ParserCombinators.Poly.ByteString
    Text.ParserCombinators.Poly.ByteStringChar
    Text.ParserCombinators.Poly.Lazy Text.ParserCombinators.Poly.Lex
    Text.ParserCombinators.Poly.Parser
    Text.ParserCombinators.Poly.Plain
    Text.ParserCombinators.Poly.Result
    Text.ParserCombinators.Poly.State
    Text.ParserCombinators.Poly.StateLazy
    Text.ParserCombinators.Poly.StateParser
    Text.ParserCombinators.Poly.StateText
    Text.ParserCombinators.Poly.Text

import-dirs:          /usr/lib/ghc-9.2.8/site-local/polyparse-1.13
library-dirs:         /usr/lib/ghc-9.2.8/site-local/polyparse-1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polyparse
hs-libraries:         HSpolyparse-1.13-I1ahtjDxVhG8wUoxrQsnyB
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-polyparse/html/polyparse.haddock
haddock-html:         /usr/share/doc/haskell-polyparse/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
